'use strict';

var alias = require('../alias-aa343af5.cjs');
var index = require('../index.cjs');
var session = require('../session-87c6f58b.cjs');

/// <reference types="@cloudflare/workers-types" />
class SQLiteD1Session extends session.SQLiteSession {
    client;
    schema;
    options;
    static [alias.entityKind] = 'SQLiteD1Session';
    logger;
    constructor(client, dialect, schema, options = {}) {
        super(dialect);
        this.client = client;
        this.schema = schema;
        this.options = options;
        this.logger = options.logger ?? new index.NoopLogger();
    }
    prepareQuery(query, fields, executeMethod, customResultMapper) {
        const stmt = this.client.prepare(query.sql);
        return new D1PreparedQuery(stmt, query, this.logger, fields, executeMethod, customResultMapper);
    }
    /*override */ async batch(queries) {
        const preparedQueries = [];
        const builtQueries = [];
        for (const query of queries) {
            const preparedQuery = query.prepare();
            const builtQuery = preparedQuery.getQuery();
            preparedQueries.push(preparedQuery);
            if (builtQuery.params.length > 0) {
                builtQueries.push(preparedQuery.stmt.bind(...builtQuery.params));
            }
            else {
                const builtQuery = preparedQuery.getQuery();
                builtQueries.push(this.client.prepare(builtQuery.sql).bind(...builtQuery.params));
            }
        }
        // const queryToType: (
        // 	| { mode: 'all' }
        // 	| {
        // 		mode: 'all_mapped';
        // 		config: { fields: SelectedFieldsOrdered; joinsNotNullableMap?: Record<string, boolean> };
        // 	}
        // 	| { mode: 'get' }
        // 	| { mode: 'values' }
        // 	| { mode: 'raw' }
        // 	| { mode: 'rqb'; mapper: any }
        // )[] = [];
        // const builtQueries: D1PreparedStatement[] = queries.map((query) => {
        // 	if (is(query, SQLiteSelectBase<any, 'async', any, any, any>)) {
        // 		const prepared = query.prepare() as D1PreparedQuery;
        // 		prepared.fields === undefined
        // 			? queryToType.push({ mode: 'all' })
        // 			: queryToType.push({
        // 				mode: 'all_mapped',
        // 				config: { fields: prepared.fields, joinsNotNullableMap: prepared.joinsNotNullableMap },
        // 			});
        // 		return prepared.stmt.bind(...prepared.params);
        // 	} else if (
        // 		is(query, SQLiteInsertBase<any, 'async', any, any>) || is(query, SQLiteUpdateBase<any, 'async', any, any>)
        // 		|| is(query, SQLiteDeleteBase<any, 'async', any, any>)
        // 	) {
        // 		const prepared = query.prepare() as D1PreparedQuery;
        // 		queryToType.push(
        // 			query.config.returning
        // 				? {
        // 					mode: 'all_mapped',
        // 					config: { fields: query.config.returning },
        // 				}
        // 				: { mode: 'raw' },
        // 		);
        // 		return prepared.stmt.bind(...prepared.params);
        // 	} else if (is(query, SQLiteRaw)) {
        // 		const builtQuery = this.dialect.sqlToQuery(query.getSQL());
        // 		queryToType.push(
        // 			query.config.action === 'run' ? { mode: 'raw' } : { mode: query.config.action },
        // 		);
        // 		return this.client.prepare(builtQuery.sql).bind(...builtQuery.params);
        // 	} else if (is(query, SQLiteRelationalQuery)) {
        // 		const preparedRqb = query.prepare() as D1PreparedQuery;
        // 		queryToType.push({ mode: 'rqb', mapper: preparedRqb.customResultMapper });
        // 		return preparedRqb.stmt.bind(...preparedRqb.params);
        // 	}
        // 	throw new DrizzleError({ message: 'You can use only drizzle queries in D1 batch API' });
        // });
        const batchResults = await this.client.batch(builtQueries);
        return batchResults.map((result, i) => preparedQueries[i].mapResult(result, true));
        // const res = this.client.batch<any>(builtQueries).then((stmt) =>
        // 	stmt.map(({ results }, index) => {
        // 		const action = queryToType[index]!;
        // 		if (action.mode === 'all') {
        // 			return results;
        // 		}
        // 		if (action.mode === 'all_mapped') {
        // 			const mappedRows = this.d1ToRawMapping(results);
        // 			return mappedRows!.map((row) => {
        // 				return mapResultRow(
        // 					action.config.fields,
        // 					row,
        // 					action.config.joinsNotNullableMap,
        // 				);
        // 			});
        // 		}
        // 		if (action.mode === 'get') {
        // 			return results![0] as unknown[];
        // 		}
        // 		if (action.mode === 'values') {
        // 			return this.d1ToRawMapping(results);
        // 		}
        // 		if (action.mode === 'raw') {
        // 			return stmt[index];
        // 		}
        // 		return action.mapper(this.d1ToRawMapping(results));
        // 	})
        // );
        // return res;
    }
    extractRawAllValueFromBatchResult(_result) {
        return _result.results;
    }
    extractRawGetValueFromBatchResult(result) {
        return result.results[0];
    }
    extractRawValuesValueFromBatchResult(result) {
        return d1ToRawMapping(result.results);
    }
    async transaction(transaction, config) {
        const tx = new D1Transaction('async', this.dialect, this, this.schema);
        await this.run(alias.sql.raw(`begin${config?.behavior ? ' ' + config.behavior : ''}`));
        try {
            const result = await transaction(tx);
            await this.run(alias.sql `commit`);
            return result;
        }
        catch (err) {
            await this.run(alias.sql `rollback`);
            throw err;
        }
    }
}
class D1Transaction extends session.SQLiteTransaction {
    static [alias.entityKind] = 'D1Transaction';
    async transaction(transaction) {
        const savepointName = `sp${this.nestedIndex}`;
        const tx = new D1Transaction('async', this.dialect, this.session, this.schema, this.nestedIndex + 1);
        await this.session.run(alias.sql.raw(`savepoint ${savepointName}`));
        try {
            const result = await transaction(tx);
            await this.session.run(alias.sql.raw(`release savepoint ${savepointName}`));
            return result;
        }
        catch (err) {
            await this.session.run(alias.sql.raw(`rollback to savepoint ${savepointName}`));
            throw err;
        }
    }
}
/**
 * This function was taken from the D1 implementation: https://github.com/cloudflare/workerd/blob/4aae9f4c7ae30a59a88ca868c4aff88bda85c956/src/cloudflare/internal/d1-api.ts#L287
 * It may cause issues with duplicated column names in join queries, which should be fixed on the D1 side.
 * @param results
 * @returns
 */
function d1ToRawMapping(results) {
    const rows = [];
    for (const row of results) {
        const entry = Object.keys(row).map((k) => row[k]);
        rows.push(entry);
    }
    return rows;
}
class D1PreparedQuery extends session.SQLitePreparedQuery {
    logger;
    static [alias.entityKind] = 'D1PreparedQuery';
    /** @internal */
    customResultMapper;
    /** @internal */
    fields;
    /** @internal */
    stmt;
    constructor(stmt, query, logger, fields, executeMethod, customResultMapper) {
        super('async', executeMethod, query);
        this.logger = logger;
        this.customResultMapper = customResultMapper;
        this.fields = fields;
        this.stmt = stmt;
    }
    run(placeholderValues) {
        const params = alias.fillPlaceholders(this.query.params, placeholderValues ?? {});
        this.logger.logQuery(this.query.sql, params);
        return this.stmt.bind(...params).run();
    }
    async all(placeholderValues) {
        const { fields, query, logger, stmt, customResultMapper } = this;
        if (!fields && !customResultMapper) {
            const params = alias.fillPlaceholders(query.params, placeholderValues ?? {});
            logger.logQuery(query.sql, params);
            return stmt.bind(...params).all().then(({ results }) => this.mapAllResult(results));
        }
        const rows = await this.values(placeholderValues);
        return this.mapAllResult(rows);
    }
    mapAllResult(rows, isFromBatch) {
        if (isFromBatch) {
            rows = d1ToRawMapping(rows.results);
        }
        if (!this.fields && !this.customResultMapper) {
            return rows;
        }
        if (this.customResultMapper) {
            return this.customResultMapper(rows);
        }
        return rows.map((row) => alias.mapResultRow(this.fields, row, this.joinsNotNullableMap));
    }
    async get(placeholderValues) {
        const { fields, joinsNotNullableMap, query, logger, stmt, customResultMapper } = this;
        if (!fields && !customResultMapper) {
            const params = alias.fillPlaceholders(query.params, placeholderValues ?? {});
            logger.logQuery(query.sql, params);
            return stmt.bind(...params).all().then(({ results }) => results[0]);
        }
        const rows = await this.values(placeholderValues);
        if (!rows[0]) {
            return undefined;
        }
        if (customResultMapper) {
            return customResultMapper(rows);
        }
        return alias.mapResultRow(fields, rows[0], joinsNotNullableMap);
    }
    mapGetResult(result, isFromBatch) {
        if (isFromBatch) {
            result = d1ToRawMapping(result.results)[0];
        }
        if (!this.fields && !this.customResultMapper) {
            return result;
        }
        if (this.customResultMapper) {
            return this.customResultMapper([result]);
        }
        return alias.mapResultRow(this.fields, result, this.joinsNotNullableMap);
    }
    values(placeholderValues) {
        const params = alias.fillPlaceholders(this.query.params, placeholderValues ?? {});
        this.logger.logQuery(this.query.sql, params);
        return this.stmt.bind(...params).raw();
    }
}

class DrizzleD1Database extends session.BaseSQLiteDatabase {
    static [alias.entityKind] = 'LibSQLDatabase';
    async batch(batch) {
        return this.session.batch(batch);
    }
}
function drizzle(client, config = {}) {
    const dialect = new session.SQLiteAsyncDialect();
    let logger;
    if (config.logger === true) {
        logger = new index.DefaultLogger();
    }
    else if (config.logger !== false) {
        logger = config.logger;
    }
    let schema;
    if (config.schema) {
        const tablesConfig = alias.extractTablesRelationalConfig(config.schema, alias.createTableRelationsHelpers);
        schema = {
            fullSchema: config.schema,
            schema: tablesConfig.tables,
            tableNamesMap: tablesConfig.tableNamesMap,
        };
    }
    const session$1 = new SQLiteD1Session(client, dialect, schema, { logger });
    return new DrizzleD1Database('async', dialect, session$1, schema);
}

exports.D1PreparedQuery = D1PreparedQuery;
exports.D1Transaction = D1Transaction;
exports.DrizzleD1Database = DrizzleD1Database;
exports.SQLiteD1Session = SQLiteD1Session;
exports.drizzle = drizzle;
//# sourceMappingURL=index.cjs.map
