'use strict';

var alias$1 = require('../alias-aa343af5.cjs');
var session = require('../session-fa66a09c.cjs');

class PgBigInt53Builder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgBigInt53Builder';
    constructor(name) {
        super(name, 'number', 'PgBigInt53');
    }
    /** @internal */
    build(table) {
        return new PgBigInt53(table, this.config);
    }
}
class PgBigInt53 extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgBigInt53';
    getSQLType() {
        return 'bigint';
    }
    mapFromDriverValue(value) {
        if (typeof value === 'number') {
            return value;
        }
        return Number(value);
    }
}
class PgBigInt64Builder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgBigInt64Builder';
    constructor(name) {
        super(name, 'bigint', 'PgBigInt64');
    }
    /** @internal */
    build(table) {
        return new PgBigInt64(table, this.config);
    }
}
class PgBigInt64 extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgBigInt64';
    getSQLType() {
        return 'bigint';
    }
    // eslint-disable-next-line unicorn/prefer-native-coercion-functions
    mapFromDriverValue(value) {
        return BigInt(value);
    }
}
function bigint(name, config) {
    if (config.mode === 'number') {
        return new PgBigInt53Builder(name);
    }
    return new PgBigInt64Builder(name);
}

class PgBigSerial53Builder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgBigSerial53Builder';
    constructor(name) {
        super(name, 'number', 'PgBigSerial53');
        this.config.hasDefault = true;
        this.config.notNull = true;
    }
    /** @internal */
    build(table) {
        return new PgBigSerial53(table, this.config);
    }
}
class PgBigSerial53 extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgBigSerial53';
    getSQLType() {
        return 'bigserial';
    }
    mapFromDriverValue(value) {
        if (typeof value === 'number') {
            return value;
        }
        return Number(value);
    }
}
class PgBigSerial64Builder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgBigSerial64Builder';
    constructor(name) {
        super(name, 'bigint', 'PgBigSerial64');
        this.config.hasDefault = true;
    }
    /** @internal */
    build(table) {
        return new PgBigSerial64(table, this.config);
    }
}
class PgBigSerial64 extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgBigSerial64';
    getSQLType() {
        return 'bigserial';
    }
    // eslint-disable-next-line unicorn/prefer-native-coercion-functions
    mapFromDriverValue(value) {
        return BigInt(value);
    }
}
function bigserial(name, { mode }) {
    if (mode === 'number') {
        return new PgBigSerial53Builder(name);
    }
    return new PgBigSerial64Builder(name);
}

class PgBooleanBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgBooleanBuilder';
    constructor(name) {
        super(name, 'boolean', 'PgBoolean');
    }
    /** @internal */
    build(table) {
        return new PgBoolean(table, this.config);
    }
}
class PgBoolean extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgBoolean';
    getSQLType() {
        return 'boolean';
    }
}
function boolean(name) {
    return new PgBooleanBuilder(name);
}

class PgCharBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgCharBuilder';
    constructor(name, config) {
        super(name, 'string', 'PgChar');
        this.config.length = config.length;
        this.config.enumValues = config.enum;
    }
    /** @internal */
    build(table) {
        return new PgChar(table, this.config);
    }
}
class PgChar extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgChar';
    length = this.config.length;
    enumValues = this.config.enumValues;
    getSQLType() {
        return this.length === undefined ? `char` : `char(${this.length})`;
    }
}
function char(name, config = {}) {
    return new PgCharBuilder(name, config);
}

class PgCidrBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgCidrBuilder';
    constructor(name) {
        super(name, 'string', 'PgCidr');
    }
    /** @internal */
    build(table) {
        return new PgCidr(table, this.config);
    }
}
class PgCidr extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgCidr';
    getSQLType() {
        return 'cidr';
    }
}
function cidr(name) {
    return new PgCidrBuilder(name);
}

class PgCustomColumnBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgCustomColumnBuilder';
    constructor(name, fieldConfig, customTypeParams) {
        super(name, 'custom', 'PgCustomColumn');
        this.config.fieldConfig = fieldConfig;
        this.config.customTypeParams = customTypeParams;
    }
    /** @internal */
    build(table) {
        return new PgCustomColumn(table, this.config);
    }
}
class PgCustomColumn extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgCustomColumn';
    sqlName;
    mapTo;
    mapFrom;
    constructor(table, config) {
        super(table, config);
        this.sqlName = config.customTypeParams.dataType(config.fieldConfig);
        this.mapTo = config.customTypeParams.toDriver;
        this.mapFrom = config.customTypeParams.fromDriver;
    }
    getSQLType() {
        return this.sqlName;
    }
    mapFromDriverValue(value) {
        return typeof this.mapFrom === 'function' ? this.mapFrom(value) : value;
    }
    mapToDriverValue(value) {
        return typeof this.mapTo === 'function' ? this.mapTo(value) : value;
    }
}
/**
 * Custom pg database data type generator
 */
function customType(customTypeParams) {
    return (dbName, fieldConfig) => {
        return new PgCustomColumnBuilder(dbName, fieldConfig, customTypeParams);
    };
}

class PgDoublePrecisionBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgDoublePrecisionBuilder';
    constructor(name) {
        super(name, 'number', 'PgDoublePrecision');
    }
    /** @internal */
    build(table) {
        return new PgDoublePrecision(table, this.config);
    }
}
class PgDoublePrecision extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgDoublePrecision';
    getSQLType() {
        return 'double precision';
    }
    mapFromDriverValue(value) {
        if (typeof value === 'string') {
            return Number.parseFloat(value);
        }
        return value;
    }
}
function doublePrecision(name) {
    return new PgDoublePrecisionBuilder(name);
}

const isPgEnumSym = Symbol.for('drizzle:isPgEnum');
function isPgEnum(obj) {
    return !!obj && typeof obj === 'function' && isPgEnumSym in obj && obj[isPgEnumSym] === true;
}
class PgEnumColumnBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgEnumColumnBuilder';
    constructor(name, enumInstance) {
        super(name, 'string', 'PgEnumColumn');
        this.config.enum = enumInstance;
    }
    /** @internal */
    build(table) {
        return new PgEnumColumn(table, this.config);
    }
}
class PgEnumColumn extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgEnumColumn';
    enum = this.config.enum;
    enumValues = this.config.enum.enumValues;
    constructor(table, config) {
        super(table, config);
        this.enum = config.enum;
    }
    getSQLType() {
        return this.enum.enumName;
    }
}
// Gratitude to zod for the enum function types
function pgEnum(enumName, values) {
    const enumInstance = Object.assign((name) => new PgEnumColumnBuilder(name, enumInstance), {
        enumName,
        enumValues: values,
        [isPgEnumSym]: true,
    });
    return enumInstance;
}

class PgInetBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgInetBuilder';
    constructor(name) {
        super(name, 'string', 'PgInet');
    }
    /** @internal */
    build(table) {
        return new PgInet(table, this.config);
    }
}
class PgInet extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgInet';
    getSQLType() {
        return 'inet';
    }
}
function inet(name) {
    return new PgInetBuilder(name);
}

class PgIntegerBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgIntegerBuilder';
    constructor(name) {
        super(name, 'number', 'PgInteger');
    }
    /** @internal */
    build(table) {
        return new PgInteger(table, this.config);
    }
}
class PgInteger extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgInteger';
    getSQLType() {
        return 'integer';
    }
    mapFromDriverValue(value) {
        if (typeof value === 'string') {
            return Number.parseInt(value);
        }
        return value;
    }
}
function integer(name) {
    return new PgIntegerBuilder(name);
}

class PgIntervalBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgIntervalBuilder';
    constructor(name, intervalConfig) {
        super(name, 'string', 'PgInterval');
        this.config.intervalConfig = intervalConfig;
    }
    /** @internal */
    build(table) {
        return new PgInterval(table, this.config);
    }
}
class PgInterval extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgInterval';
    fields = this.config.intervalConfig.fields;
    precision = this.config.intervalConfig.precision;
    getSQLType() {
        const fields = this.fields ? ` ${this.fields}` : '';
        const precision = this.precision ? `(${this.precision})` : '';
        return `interval${fields}${precision}`;
    }
}
function interval(name, config = {}) {
    return new PgIntervalBuilder(name, config);
}

class PgMacaddrBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgMacaddrBuilder';
    constructor(name) {
        super(name, 'string', 'PgMacaddr');
    }
    /** @internal */
    build(table) {
        return new PgMacaddr(table, this.config);
    }
}
class PgMacaddr extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgMacaddr';
    getSQLType() {
        return 'macaddr';
    }
}
function macaddr(name) {
    return new PgMacaddrBuilder(name);
}

class PgMacaddr8Builder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgMacaddr8Builder';
    constructor(name) {
        super(name, 'string', 'PgMacaddr8');
    }
    /** @internal */
    build(table) {
        return new PgMacaddr8(table, this.config);
    }
}
class PgMacaddr8 extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgMacaddr8';
    getSQLType() {
        return 'macaddr8';
    }
}
function macaddr8(name) {
    return new PgMacaddr8Builder(name);
}

class PgRealBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgRealBuilder';
    constructor(name, length) {
        super(name, 'number', 'PgReal');
        this.config.length = length;
    }
    /** @internal */
    build(table) {
        return new PgReal(table, this.config);
    }
}
class PgReal extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgReal';
    constructor(table, config) {
        super(table, config);
    }
    getSQLType() {
        return 'real';
    }
    mapFromDriverValue = (value) => {
        if (typeof value === 'string') {
            return Number.parseFloat(value);
        }
        return value;
    };
}
function real(name) {
    return new PgRealBuilder(name);
}

class PgSerialBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgSerialBuilder';
    constructor(name) {
        super(name, 'number', 'PgSerial');
        this.config.hasDefault = true;
        this.config.notNull = true;
    }
    /** @internal */
    build(table) {
        return new PgSerial(table, this.config);
    }
}
class PgSerial extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgSerial';
    getSQLType() {
        return 'serial';
    }
}
function serial(name) {
    return new PgSerialBuilder(name);
}

class PgSmallIntBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgSmallIntBuilder';
    constructor(name) {
        super(name, 'number', 'PgSmallInt');
    }
    /** @internal */
    build(table) {
        return new PgSmallInt(table, this.config);
    }
}
class PgSmallInt extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgSmallInt';
    getSQLType() {
        return 'smallint';
    }
    mapFromDriverValue = (value) => {
        if (typeof value === 'string') {
            return Number(value);
        }
        return value;
    };
}
function smallint(name) {
    return new PgSmallIntBuilder(name);
}

class PgSmallSerialBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgSmallSerialBuilder';
    constructor(name) {
        super(name, 'number', 'PgSmallSerial');
        this.config.hasDefault = true;
        this.config.notNull = true;
    }
    /** @internal */
    build(table) {
        return new PgSmallSerial(table, this.config);
    }
}
class PgSmallSerial extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgSmallSerial';
    getSQLType() {
        return 'smallserial';
    }
}
function smallserial(name) {
    return new PgSmallSerialBuilder(name);
}

class PgTextBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgTextBuilder';
    constructor(name, config) {
        super(name, 'string', 'PgText');
        this.config.enumValues = config.enum;
    }
    /** @internal */
    build(table) {
        return new PgText(table, this.config);
    }
}
class PgText extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgText';
    enumValues = this.config.enumValues;
    getSQLType() {
        return 'text';
    }
}
function text(name, config = {}) {
    return new PgTextBuilder(name, config);
}

class PgVarcharBuilder extends alias$1.PgColumnBuilder {
    static [alias$1.entityKind] = 'PgVarcharBuilder';
    constructor(name, config) {
        super(name, 'string', 'PgVarchar');
        this.config.length = config.length;
        this.config.enumValues = config.enum;
    }
    /** @internal */
    build(table) {
        return new PgVarchar(table, this.config);
    }
}
class PgVarchar extends alias$1.PgColumn {
    static [alias$1.entityKind] = 'PgVarchar';
    length = this.config.length;
    enumValues = this.config.enumValues;
    getSQLType() {
        return this.length === undefined ? `varchar` : `varchar(${this.length})`;
    }
}
function varchar(name, config = {}) {
    return new PgVarcharBuilder(name, config);
}

function alias(table, alias) {
    return new Proxy(table, new alias$1.TableAliasProxyHandler(alias, false));
}

class CheckBuilder {
    name;
    value;
    static [alias$1.entityKind] = 'PgCheckBuilder';
    brand;
    constructor(name, value) {
        this.name = name;
        this.value = value;
    }
    /** @internal */
    build(table) {
        return new Check(table, this);
    }
}
class Check {
    table;
    static [alias$1.entityKind] = 'PgCheck';
    name;
    value;
    constructor(table, builder) {
        this.table = table;
        this.name = builder.name;
        this.value = builder.value;
    }
}
function check(name, value) {
    return new CheckBuilder(name, value);
}

class IndexBuilderOn {
    unique;
    name;
    static [alias$1.entityKind] = 'PgIndexBuilderOn';
    constructor(unique, name) {
        this.unique = unique;
        this.name = name;
    }
    on(...columns) {
        return new IndexBuilder(columns, this.unique, false, this.name);
    }
    onOnly(...columns) {
        return new IndexBuilder(columns, this.unique, true, this.name);
    }
}
class IndexBuilder {
    static [alias$1.entityKind] = 'PgIndexBuilder';
    /** @internal */
    config;
    constructor(columns, unique, only, name) {
        this.config = {
            name,
            columns,
            unique,
            only,
        };
    }
    concurrently() {
        this.config.concurrently = true;
        return this;
    }
    using(method) {
        this.config.using = method;
        return this;
    }
    asc() {
        this.config.order = 'asc';
        return this;
    }
    desc() {
        this.config.order = 'desc';
        return this;
    }
    nullsFirst() {
        this.config.nulls = 'first';
        return this;
    }
    nullsLast() {
        this.config.nulls = 'last';
        return this;
    }
    where(condition) {
        this.config.where = condition;
        return this;
    }
    /** @internal */
    build(table) {
        return new Index(this.config, table);
    }
}
class Index {
    static [alias$1.entityKind] = 'PgIndex';
    config;
    constructor(config, table) {
        this.config = { ...config, table };
    }
}
function index(name) {
    return new IndexBuilderOn(false, name);
}
function uniqueIndex(name) {
    return new IndexBuilderOn(true, name);
}

class PgSchema {
    schemaName;
    static [alias$1.entityKind] = 'PgSchema';
    constructor(schemaName) {
        this.schemaName = schemaName;
    }
    table = ((name, columns, extraConfig) => {
        return alias$1.pgTableWithSchema(name, columns, extraConfig, this.schemaName);
    });
    view = ((name, columns) => {
        return alias$1.pgViewWithSchema(name, columns, this.schemaName);
    });
    materializedView = ((name, columns) => {
        return alias$1.pgMaterializedViewWithSchema(name, columns, this.schemaName);
    });
}
function isPgSchema(obj) {
    return alias$1.is(obj, PgSchema);
}
function pgSchema(name) {
    if (name === 'public') {
        throw new Error(`You can't specify 'public' as schema name. Postgres is using public schema by default. If you want to use 'public' schema, just use pgTable() instead of creating a schema`);
    }
    return new PgSchema(name);
}

function getTableConfig(table) {
    const columns = Object.values(table[alias$1.Table.Symbol.Columns]);
    const indexes = [];
    const checks = [];
    const primaryKeys = [];
    const foreignKeys = Object.values(table[alias$1.PgTable.Symbol.InlineForeignKeys]);
    const uniqueConstraints = [];
    const name = table[alias$1.Table.Symbol.Name];
    const schema = table[alias$1.Table.Symbol.Schema];
    const extraConfigBuilder = table[alias$1.PgTable.Symbol.ExtraConfigBuilder];
    if (extraConfigBuilder !== undefined) {
        const extraConfig = extraConfigBuilder(table[alias$1.Table.Symbol.Columns]);
        for (const builder of Object.values(extraConfig)) {
            if (alias$1.is(builder, IndexBuilder)) {
                indexes.push(builder.build(table));
            }
            else if (alias$1.is(builder, CheckBuilder)) {
                checks.push(builder.build(table));
            }
            else if (alias$1.is(builder, alias$1.UniqueConstraintBuilder)) {
                uniqueConstraints.push(builder.build(table));
            }
            else if (alias$1.is(builder, alias$1.PrimaryKeyBuilder)) {
                primaryKeys.push(builder.build(table));
            }
            else if (alias$1.is(builder, alias$1.ForeignKeyBuilder)) {
                foreignKeys.push(builder.build(table));
            }
        }
    }
    return {
        columns,
        indexes,
        foreignKeys,
        checks,
        primaryKeys,
        uniqueConstraints,
        name,
        schema,
    };
}
function getViewConfig(view) {
    return {
        ...view[alias$1.ViewBaseConfig],
        ...view[alias$1.PgViewConfig],
    };
}
function getMaterializedViewConfig(view) {
    return {
        ...view[alias$1.ViewBaseConfig],
        ...view[alias$1.PgMaterializedViewConfig],
    };
}

exports.DefaultViewBuilderCore = alias$1.DefaultViewBuilderCore;
exports.ForeignKey = alias$1.ForeignKey;
exports.ForeignKeyBuilder = alias$1.ForeignKeyBuilder;
exports.InlineForeignKeys = alias$1.InlineForeignKeys;
exports.ManualMaterializedViewBuilder = alias$1.ManualMaterializedViewBuilder;
exports.ManualViewBuilder = alias$1.ManualViewBuilder;
exports.MaterializedViewBuilder = alias$1.MaterializedViewBuilder;
exports.MaterializedViewBuilderCore = alias$1.MaterializedViewBuilderCore;
exports.PgArray = alias$1.PgArray;
exports.PgArrayBuilder = alias$1.PgArrayBuilder;
exports.PgColumn = alias$1.PgColumn;
exports.PgColumnBuilder = alias$1.PgColumnBuilder;
exports.PgDate = alias$1.PgDate;
exports.PgDateBuilder = alias$1.PgDateBuilder;
exports.PgDateString = alias$1.PgDateString;
exports.PgDateStringBuilder = alias$1.PgDateStringBuilder;
exports.PgDialect = alias$1.PgDialect;
exports.PgJson = alias$1.PgJson;
exports.PgJsonBuilder = alias$1.PgJsonBuilder;
exports.PgJsonb = alias$1.PgJsonb;
exports.PgJsonbBuilder = alias$1.PgJsonbBuilder;
exports.PgMaterializedView = alias$1.PgMaterializedView;
exports.PgMaterializedViewConfig = alias$1.PgMaterializedViewConfig;
exports.PgNumeric = alias$1.PgNumeric;
exports.PgNumericBuilder = alias$1.PgNumericBuilder;
exports.PgSelectBase = alias$1.PgSelectBase;
exports.PgSelectBuilder = alias$1.PgSelectBuilder;
exports.PgSelectQueryBuilderBase = alias$1.PgSelectQueryBuilderBase;
exports.PgTable = alias$1.PgTable;
exports.PgTime = alias$1.PgTime;
exports.PgTimeBuilder = alias$1.PgTimeBuilder;
exports.PgTimestamp = alias$1.PgTimestamp;
exports.PgTimestampBuilder = alias$1.PgTimestampBuilder;
exports.PgTimestampString = alias$1.PgTimestampString;
exports.PgTimestampStringBuilder = alias$1.PgTimestampStringBuilder;
exports.PgUUID = alias$1.PgUUID;
exports.PgUUIDBuilder = alias$1.PgUUIDBuilder;
exports.PgView = alias$1.PgView;
exports.PgViewBase = alias$1.PgViewBase;
exports.PgViewConfig = alias$1.PgViewConfig;
exports.PrimaryKey = alias$1.PrimaryKey;
exports.PrimaryKeyBuilder = alias$1.PrimaryKeyBuilder;
exports.QueryBuilder = alias$1.QueryBuilder;
exports.UniqueConstraint = alias$1.UniqueConstraint;
exports.UniqueConstraintBuilder = alias$1.UniqueConstraintBuilder;
exports.UniqueOnConstraintBuilder = alias$1.UniqueOnConstraintBuilder;
exports.ViewBuilder = alias$1.ViewBuilder;
exports.date = alias$1.date;
exports.decimal = alias$1.decimal;
exports.foreignKey = alias$1.foreignKey;
exports.json = alias$1.json;
exports.jsonb = alias$1.jsonb;
exports.makePgArray = alias$1.makePgArray;
exports.numeric = alias$1.numeric;
exports.parsePgArray = alias$1.parsePgArray;
exports.parsePgNestedArray = alias$1.parsePgNestedArray;
exports.pgMaterializedView = alias$1.pgMaterializedView;
exports.pgMaterializedViewWithSchema = alias$1.pgMaterializedViewWithSchema;
exports.pgTable = alias$1.pgTable;
exports.pgTableCreator = alias$1.pgTableCreator;
exports.pgTableWithSchema = alias$1.pgTableWithSchema;
exports.pgView = alias$1.pgView;
exports.pgViewWithSchema = alias$1.pgViewWithSchema;
exports.primaryKey = alias$1.primaryKey;
exports.time = alias$1.time;
exports.timestamp = alias$1.timestamp;
exports.unique = alias$1.unique;
exports.uniqueKeyName = alias$1.uniqueKeyName;
exports.uuid = alias$1.uuid;
exports.PgDatabase = session.PgDatabase;
exports.PgDeleteBase = session.PgDeleteBase;
exports.PgInsertBase = session.PgInsertBase;
exports.PgInsertBuilder = session.PgInsertBuilder;
exports.PgRefreshMaterializedView = session.PgRefreshMaterializedView;
exports.PgSession = session.PgSession;
exports.PgTransaction = session.PgTransaction;
exports.PgUpdateBase = session.PgUpdateBase;
exports.PgUpdateBuilder = session.PgUpdateBuilder;
exports.PreparedQuery = session.PreparedQuery;
exports.Check = Check;
exports.CheckBuilder = CheckBuilder;
exports.Index = Index;
exports.IndexBuilder = IndexBuilder;
exports.IndexBuilderOn = IndexBuilderOn;
exports.PgBigInt53 = PgBigInt53;
exports.PgBigInt53Builder = PgBigInt53Builder;
exports.PgBigInt64 = PgBigInt64;
exports.PgBigInt64Builder = PgBigInt64Builder;
exports.PgBigSerial53 = PgBigSerial53;
exports.PgBigSerial53Builder = PgBigSerial53Builder;
exports.PgBigSerial64 = PgBigSerial64;
exports.PgBigSerial64Builder = PgBigSerial64Builder;
exports.PgBoolean = PgBoolean;
exports.PgBooleanBuilder = PgBooleanBuilder;
exports.PgChar = PgChar;
exports.PgCharBuilder = PgCharBuilder;
exports.PgCidr = PgCidr;
exports.PgCidrBuilder = PgCidrBuilder;
exports.PgCustomColumn = PgCustomColumn;
exports.PgCustomColumnBuilder = PgCustomColumnBuilder;
exports.PgDoublePrecision = PgDoublePrecision;
exports.PgDoublePrecisionBuilder = PgDoublePrecisionBuilder;
exports.PgEnumColumn = PgEnumColumn;
exports.PgEnumColumnBuilder = PgEnumColumnBuilder;
exports.PgInet = PgInet;
exports.PgInetBuilder = PgInetBuilder;
exports.PgInteger = PgInteger;
exports.PgIntegerBuilder = PgIntegerBuilder;
exports.PgInterval = PgInterval;
exports.PgIntervalBuilder = PgIntervalBuilder;
exports.PgMacaddr = PgMacaddr;
exports.PgMacaddr8 = PgMacaddr8;
exports.PgMacaddr8Builder = PgMacaddr8Builder;
exports.PgMacaddrBuilder = PgMacaddrBuilder;
exports.PgReal = PgReal;
exports.PgRealBuilder = PgRealBuilder;
exports.PgSchema = PgSchema;
exports.PgSerial = PgSerial;
exports.PgSerialBuilder = PgSerialBuilder;
exports.PgSmallInt = PgSmallInt;
exports.PgSmallIntBuilder = PgSmallIntBuilder;
exports.PgSmallSerial = PgSmallSerial;
exports.PgSmallSerialBuilder = PgSmallSerialBuilder;
exports.PgText = PgText;
exports.PgTextBuilder = PgTextBuilder;
exports.PgVarchar = PgVarchar;
exports.PgVarcharBuilder = PgVarcharBuilder;
exports.alias = alias;
exports.bigint = bigint;
exports.bigserial = bigserial;
exports.boolean = boolean;
exports.char = char;
exports.check = check;
exports.cidr = cidr;
exports.customType = customType;
exports.doublePrecision = doublePrecision;
exports.getMaterializedViewConfig = getMaterializedViewConfig;
exports.getTableConfig = getTableConfig;
exports.getViewConfig = getViewConfig;
exports.index = index;
exports.inet = inet;
exports.integer = integer;
exports.interval = interval;
exports.isPgEnum = isPgEnum;
exports.isPgSchema = isPgSchema;
exports.macaddr = macaddr;
exports.macaddr8 = macaddr8;
exports.pgEnum = pgEnum;
exports.pgSchema = pgSchema;
exports.real = real;
exports.serial = serial;
exports.smallint = smallint;
exports.smallserial = smallserial;
exports.text = text;
exports.uniqueIndex = uniqueIndex;
exports.varchar = varchar;
//# sourceMappingURL=index.cjs.map
